@@ -1,6 +1,6 @@
 import json
 import requests
-from transcriptic.objects import Run, Project
+from transcriptic.objects import Run, Project, Aliquot, Resource, Container
 
 ctx = None
 
@@ -10,37 +10,38 @@ class AnalysisException(Exception):
   def __str__(self):
     return self.message
 
-def _check_ctx(force_ctx):
-  if not ctx and not force_ctx:
+def _check_ctx():
+  if not ctx:
     raise Exception("No transcriptic.config.Connection context found!")
 
-def _get_object(id, klass, force_ctx = None):
-  _check_ctx(force_ctx)
+def _get_object(id, klass):
+  _check_ctx()
   req = ctx.get("/-/%s" % id)
   if req.status_code == 200:
     data = req.json()
-    return klass(data['id'], data)
+    return klass(data['id'], data, connection = ctx)
   elif req.status_code == 404:
     raise Exception("[404] No object found for ID " + id)
   else:
     raise Exception("[%d] %s" % (req.status_code, req.text))
 
-def run(id, force_ctx = None):
-  _get_object(id, Run, force_ctx = force_ctx)
+def run(id):
+  return _get_object(id, Run)
 
-def project(id, force_ctx = None):
-  _get_object(id, Project, force_ctx = force_ctx)
+def project(id):
+  return _get_object(id, Project)
 
-def container(id, force_ctx = None):
-  _check_ctx(force_ctx)
-  req = ctx.get("containers/%s" % id)
-  if req.status_code == 200:
-    return req.json()
-  else:
-    raise Exception(req.json())
+def resource(id):
+  return _get_object(id, Resource)
 
-def analyze(protocol, test_mode = False, force_ctx = None):
-  _check_ctx(force_ctx)
+def aliquot(id):
+  return _get_object(id, Aliquot)
+
+def container(id):
+  return _get_object(id, Container)
+
+def analyze(protocol, test_mode = False):
+  _check_ctx()
   req = ctx.post('analyze_run', data = json.dumps({
     "protocol": protocol,
     "test_mode": test_mode
@@ -55,10 +56,27 @@ def analyze(protocol, test_mode = False, force_ctx = None):
   else:
     raise Exception("[%d] %s" % (req.status_code, req.text))
 
+def submit(protocol, project, title = None, test_mode = False):
+  _check_ctx()
+  req = ctx.post('%s/runs' % project, data = json.dumps({
+    "title": title,
+    "protocol": protocol,
+    "test_mode": test_mode
+  }))
+  if req.status_code == 201:
+    return req.json()
+  elif req.status_code == 404:
+    raise AnalysisException("Error: Couldn't create run (404). \nAre you sure the project %s "
+               "exists, and that you have access to it?" % ctx.url(project))
+  elif req.status_code == 422:
+    raise AnalysisException("Error creating run: %s" % req.text)
+  else:
+    raise Exception("[%d] %s" % (req.status_code, req.text))
+
 def dataset(id, key = "*"):
   _check_ctx()
-  req = ctx.get("data/%s.json?key=%s" % (id, key))
+  req = ctx.get("/data/%s.json?key=%s" % (id, key))
   if req.status_code == 200:
     return req.json()
   else:
-    raise Exception(req.json())
+    raise Exception("[%d] %s" % (req.status_code, req.text))
